Learn R Programming

DHBins (version 1.1)

dhb_cars: Cars per household in New Zealand

Description

The distribution of cars per household across New Zealand District Health Boards, based on data from the 2013 Census

Usage

data("dhb_cars")

Arguments

Format

A data frame with 20 observations on the following 5 variables.

dhb

District Health Board name

none

Number of households with no cars

one

Number of households with one car

two

Number of households with two cars

more

Number of households with three or more cars

Examples

Run this code
# NOT RUN {
data(dhb_cars)
tris<-tri_alloc(dhb_cars[,-1], c("green","gold","orange","goldenrod"), names=dhb_cars$dhb )

dhtri(tri_colours=tris,
  legend=list(fill=c("green","gold","orange","goldenrod"),
         border=NA,
         legend=c("0","1","2","3+"),
         title="Cars/Household")
)
# }

Run the code above in your browser using DataLab