Learn R Programming

DHBins (version 1.1)

region_ethnicity: Ethnic makeup of New Zealand, by region

Description

Number of people, by ethnicity, for the New Zealand regions, based on the 2013 Estimated Resident Population.

Usage

data("region_ethnicity")

Arguments

Format

A data frame with 16 observations on the following 6 variables.

Area

a factor with level Auckland region Bay of Plenty region Canterbury region Gisborne region Hawke\'s Bay region Manawatu-Wanganui region Marlborough region Nelson region Northland region Otago region Southland region Taranaki region Tasman region Waikato region Wellington region West Coast region

Asian

number of people

Euro_Other

number of people

Maori

number of people

MELAA

number of people

Pacific

number of people

Examples

Run this code
# NOT RUN {
data(region_ethnicity)
summary(region_ethnicity)
# }

Run the code above in your browser using DataLab